@@ -30,16 +30,10 @@
 #define SSH_BUFSIZ 131072
 #endif
 
-#ifndef MIN
-#define MIN(a,b) (a) < (b) ? (a) : (b)
-#endif
-
 /* from libssh examples */
 static int verify_knownhost(ssh_session session)
 {
   unsigned char *hash = NULL;
-  char *hexa;
-  char buf[10];
 
   int state = ssh_is_server_known(session);
   int hlen = ssh_get_pubkey_hash(session, &hash);
@@ -73,20 +67,32 @@ static int verify_knownhost(ssh_session session)
       /* fallback to SSH_SERVER_NOT_KNOWN behavior */
 
     case SSH_SERVER_NOT_KNOWN:
-      hexa = ssh_get_hexa(hash, hlen);
-      fprintf(stderr, _("The server is unknown. Do you trust the host key?\n"));
-      fprintf(stderr, _("Public key hash: %s\n"), hexa);
+    {
+      char* hexa = ssh_get_hexa(hash, hlen);
+      fprintf(stderr, _("The server is unknown. Public key hash: %s\n"), hexa);
       free(hexa);
+      fprintf(stderr, _("Do you trust the host key? [yes/No] "));
+      fflush(stderr);
+
+      char buf[64] = { '\0' };
       if (fgets(buf, sizeof(buf), stdin) == NULL)
       {
         free(hash);
         return -1;
       }
-      if (strncasecmp(buf, "yes", 3) != 0)
+
+      /* replace \n from fgets with \0 */
+      const size_t len = strlen(buf);
+      if (len > 0 && buf[len - 1] == '\n') {
+        buf[len - 1] = '\0';
+      }
+
+      if (strcasecmp(buf, _("yes")) != 0 && strcasecmp(buf, "yes") != 0)
       {
         free(hash);
         return -1;
       }
+
       if (ssh_write_knownhost(session) < 0)
       {
         fprintf(stderr, _("Error %s\n"), strerror(errno));
@@ -94,6 +100,7 @@ static int verify_knownhost(ssh_session session)
         return -1;
       }
       break;
+    }
 
     case SSH_SERVER_ERROR:
       fprintf(stderr, _("Error %s\n"), ssh_get_error(session));
@@ -323,6 +330,8 @@ int ssh_open_url(url_t* urlp)
 
   ftp->connected = true;
   ftp->loggedin = true;
+  // code does not make sense for sftp connection
+  ftp->code = ctComplete;
 
   free(ftp->homedir);
   ftp->homedir = ftp_getcurdir();
@@ -444,8 +453,6 @@ int ssh_unlink(const char *path)
   if (rc != SSH_OK && sftp_get_error(ftp->sftp_session) != SSH_FX_NO_SUCH_FILE)
   {
     ftp_err(_("Couldn't delete file: %s\n"), ssh_get_error(ftp->session));
-    ftp->code = ctError;
-    ftp->fullcode = 500;
     return -1;
   }
   else
@@ -1009,3 +1016,22 @@ int ssh_send(const char *path, FILE *fp, putmode_t how,
   transfer_finished();
   return r;
 }
+
+char* ssh_connected_user()
+{
+  if (!ftp->session)
+    return NULL;
+
+#if LIBSSH_VERSION_INT >= SSH_VERSION_INT(0, 6, 1)
+  char* user = NULL;
+  if (ssh_options_get(ftp->session, SSH_OPTIONS_USER, &user) != SSH_OK)
+    return NULL;
+
+  char* ret = xstrdup(user);
+  ssh_string_free_char(user);
+#else
+  char* ret = xstrdup("[not available]");
+#endif
+
+  return ret;
+}
