@@ -41,6 +41,7 @@
 
 /* C99 headers */
 #include <stdint.h>
+#include <limits.h>
 #include <stdbool.h>
 #include <stdio.h>
 #include <string.h>
@@ -161,7 +162,7 @@ extern int read_history ();
 #define HAVE_LIBREADLINE
 #endif
 
-#if defined(HAVE_LIBEDIT) || (defined(HAVE_LIBREADLINE) && RL_READLINE_VERSION < 0x0603)
+#if defined(HAVE_LIBEDIT) || (defined(HAVE_LIBREADLINE) && RL_READLINE_VERSION < 0x0602)
 typedef CPPFunction rl_completion_func_t;
 #endif
 
@@ -216,4 +217,12 @@ typedef void (*sighandler_t)(int);
 #define test(a, b)   (((a) & (b)) == (b))
 #define STD_SHELL "/bin/sh"
 
+#ifndef MIN
+#define MIN(a, b) (a) < (b) ? (a) : (b)
+#endif
+
+#ifndef MAX
+#define MAX(a, b) (a) < (b) ? (b) : (a)
+#endif
+
 #endif
